@@ -176,7 +176,10 @@ update_parse (DroplineData *data, const gchar *mesg)
 		lines = g_strsplit (mesg, "\n", MAX_FILES);
 		for (i = 0; lines [i]; i++)
 		{
-			if (strstr (lines [i], ":obsolete:"))
+			if (strstr (lines [i], ":obsolete_lib:") ||
+				strstr (lines [i], ":obsolete_app:") ||
+				strstr (lines [i], ":obsolete:") ||
+				strstr (lines [i], ":replaced:"))
 				lines [i] = '\0';
 			else
 			{
